/*  GTKtalog.
 *  Copyright (C) 2000 Yves Mettier
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef __COMPARE_H__
#define __COMPARE_H__

#include <config.h>
#include <gnome.h>

gint compare(const gchar *pattern, const gchar *string, gint regex, gboolean case_sensitive);
char *convert_string_with_slashes (gchar * s);
GPtrArray *extract_field (const gchar * string, const gchar * separator, GArray *field, int nb_fields);

#endif
